@@ -221,15 +221,28 @@ class Config:
 
         # 验证必需的配置项
         required_configs = [
-            ("embedding.api_key", "Embedding API 密钥"),
-            ("database.sqlite.db_path", "SQLite 数据库路径"),
-            ("database.chromadb.persist_dir", "ChromaDB 持久化目录"),
-            ("database.chromadb.collection_name", "ChromaDB Collection 名称"),
+            ("embedding.api_key", "Embedding API 密钥", "EMBEDDING_API_KEY"),
+            ("database.sqlite.db_path", "SQLite 数据库路径", "SQLITE_DB_PATH"),
+            ("database.chromadb.persist_dir", "ChromaDB 持久化目录", "CHROMA_PERSIST_DIR"),
+            ("database.chromadb.collection_name", "ChromaDB Collection 名称", "CHROMA_COLLECTION_NAME"),
         ]
 
-        for key, description in required_configs:
-            if not self._get_nested(key):
-                errors.append(f"缺少必需配置: {description} ({key})")
+        for key, description, env_var in required_configs:
+            value = self._get_nested(key)
+            if not value:
+                # 检查环境变量是否存在，提供更详细的错误信息
+                env_value = os.getenv(env_var)
+                if env_value:
+                    # 环境变量存在但未被正确加载，这是一个 bug
+                    errors.append(
+                        f"缺少必需配置: {description} ({key})\n"
+                        f"  环境变量 {env_var} 已设置但未被正确加载"
+                    )
+                else:
+                    errors.append(
+                        f"缺少必需配置: {description} ({key})\n"
+                        f"  请设置环境变量: {env_var}"
+                    )
 
         # 验证路径配置，自动创建目录
         db_path = self._get_nested("database.sqlite.db_path")
