@@ -153,8 +153,13 @@ class Logger:
         return True
 
     def _create_console_handler(self, formatter: logging.Formatter) -> logging.Handler:
-        """创建控制台处理器"""
-        console_handler = logging.StreamHandler(sys.stdout)
+        """创建控制台处理器
+        
+        注意：为了支持 MCP STDIO 通信，控制台日志输出到 stderr
+        而不是 stdout，因为 stdout 用于 MCP JSON-RPC 消息传输
+        """
+        # 重要：输出到 stderr 而不是 stdout，避免干扰 MCP 协议通信
+        console_handler = logging.StreamHandler(sys.stderr)
 
         # 获取控制台日志级别
         if self.config:
