@@ -17,12 +17,16 @@ import importlib.metadata
 # Windows 控制台编码处理
 if sys.platform == 'win32':
     try:
-        # 设置 stdout 为 UTF-8 编码
+        # 设置 stdout/stderr/stdin 为 UTF-8 编码，用于 MCP STDIO 通信
         import io
-        sys.stdout = io.TextIOWrapper(sys.stdout.buffer, encoding='utf-8', errors='replace')
-        sys.stderr = io.TextIOWrapper(sys.stderr.buffer, encoding='utf-8', errors='replace')
-    except Exception:
-        pass  # 忽略编码设置失败
+        # line_buffering=True 确保每行立即刷新，这对 JSON-RPC 通信至关重要
+        sys.stdout = io.TextIOWrapper(sys.stdout.buffer, encoding='utf-8', errors='replace', line_buffering=True)
+        sys.stderr = io.TextIOWrapper(sys.stderr.buffer, encoding='utf-8', errors='replace', line_buffering=True)
+        # 同时设置 stdin 编码，确保能正确读取 MCP 消息
+        sys.stdin = io.TextIOWrapper(sys.stdin.buffer, encoding='utf-8', errors='replace')
+    except Exception as e:
+        # 如果设置失败，记录错误但继续运行
+        print(f"Warning: Failed to set UTF-8 encoding: {e}", file=sys.stderr)
 
 # 尝试导入 TOML 解析库（仅用于开发环境）
 try:
@@ -116,18 +120,25 @@ def initialize_system():
         tuple: (config, logger) 配置和日志实例
     """
     global config, logger
+    
+    # 检测是否在 MCP 模式下运行
+    is_mcp_mode = not sys.stdin.isatty() if hasattr(sys.stdin, 'isatty') else False
 
     try:
         # 1. 加载配置
-        print("正在加载配置...")
+        if not is_mcp_mode:
+            print("正在加载配置...")
         config = get_config()
-        print("[OK] 配置加载成功")
+        if not is_mcp_mode:
+            print("[OK] 配置加载成功")
 
         # 2. 初始化日志系统
-        print("正在初始化日志系统...")
+        if not is_mcp_mode:
+            print("正在初始化日志系统...")
         logger = setup_logger(config)
         logger.info("日志系统初始化成功")
-        print("[OK] 日志系统初始化成功")
+        if not is_mcp_mode:
+            print("[OK] 日志系统初始化成功")
 
         # 3. 验证关键配置
         logger.info("验证关键配置...")
@@ -136,12 +147,18 @@ def initialize_system():
         logger.info(f"- ChromaDB Collection 名称: {config.chromadb_collection_name}")
         logger.info(f"- Embedding API 端点: {config.embedding_api_endpoint}")
         logger.info(f"- 日志级别: {config.log_level}")
-        print("[OK] 配置验证完成")
+        if not is_mcp_mode:
+            print("[OK] 配置验证完成")
 
         return config, logger
 
     except Exception as e:
-        print(f"[ERROR] 系统初始化失败: {e}")
+        error_msg = f"[ERROR] 系统初始化失败: {e}"
+        if is_mcp_mode:
+            # MCP 模式下，输出到 stderr
+            print(error_msg, file=sys.stderr)
+        else:
+            print(error_msg)
         sys.exit(1)
 
 
@@ -155,10 +172,10 @@ def create_mcp_server(config, logger):
     try:
         logger.info("创建 FastMCP Server...")
 
-        # 创建 MCP Server
+        # 创建 MCP Server - 使用动态版本号
         server = FastMCP(
             name=config.get("server.name", "questions_mcp_server"),
-            version=config.get("server.version", "1.0.0"),
+            version=get_version(),  # 使用 get_version() 动态获取版本号
         )
 
         logger.info("[OK] FastMCP Server 创建成功")
@@ -291,7 +308,7 @@ def register_tools(server: FastMCP, config, logger):
             result = {
                 "status": "healthy",
                 "service": "questions_mcp_server",
-                "version": config.get("server.version", "1.0.0"),
+                "version": get_version(),  # 使用动态版本号
                 "components": {
                     "config": "loaded",
                     "logger": "active",
@@ -329,7 +346,7 @@ def register_tools(server: FastMCP, config, logger):
         try:
             info = {
                 "name": config.get("server.name", "questions_mcp_server"),
-                "version": config.get("server.version", "1.0.0"),
+                "version": get_version(),  # 使用动态版本号
                 "description": config.get(
                     "server.description", "题目管理与检索系统 MCP Server"
                 ),
@@ -1409,36 +1426,50 @@ def main():
     程序入口，负责初始化系统并启动 MCP Server。
     """
     global mcp_server, config, logger
-
-    print("=" * 60)
-    print("Questions MCP Server - 题目管理与检索系统")
-    print(f"Version: {get_version()}")
-    print("=" * 60)
-    print()
+    
+    # 检测是否在 MCP 模式下运行（通过 STDIO 通信）
+    # 如果 stdin 不是 tty，则可能是 MCP 客户端连接
+    is_mcp_mode = not sys.stdin.isatty() if hasattr(sys.stdin, 'isatty') else False
+    
+    # 只在非-MCP 模式下显示启动信息
+    if not is_mcp_mode:
+        print("=" * 60)
+        print("Questions MCP Server - 题目管理与检索系统")
+        print(f"Version: {get_version()}")
+        print("=" * 60)
+        print()
 
     try:
         # 1. 初始化系统
-        print("阶段 1: 初始化系统...")
+        if not is_mcp_mode:
+            print("阶段 1: 初始化系统...")
         config, logger = initialize_system()
-        print()
+        if not is_mcp_mode:
+            print()
 
         # 2. 创建 MCP Server
-        print("阶段 2: 创建 MCP Server...")
+        if not is_mcp_mode:
+            print("阶段 2: 创建 MCP Server...")
         mcp_server = create_mcp_server(config, logger)
-        print("[OK] MCP Server 创建成功")
-        print()
+        if not is_mcp_mode:
+            print("[OK] MCP Server 创建成功")
+            print()
 
         # 3. 初始化服务
-        print("阶段3: 初始化服务...")
+        if not is_mcp_mode:
+            print("阶段3: 初始化服务...")
         db_manager, management_service, search_service, import_service, analytics_service, export_service = initialize_services(config, logger)
-        print("[OK] 服务初始化完成")
-        print()
+        if not is_mcp_mode:
+            print("[OK] 服务初始化完成")
+            print()
 
         # 4. 注册 Tools
-        print("阶段 4: 注册 MCP Tools...")
+        if not is_mcp_mode:
+            print("阶段 4: 注册 MCP Tools...")
         register_tools(mcp_server, config, logger)
-        print("[OK] Tools 注册完成")
-        print()
+        if not is_mcp_mode:
+            print("[OK] Tools 注册完成")
+            print()
 
         # 5. 注册信号处理器（用于优雅关闭）
         def shutdown_handler(signum, frame):
@@ -1455,7 +1486,7 @@ def main():
                 # 这里可以添加数据库连接关闭等清理逻辑
                 logger.info("清理完成，服务已停止")
             else:
-                print(f"收到关闭信号 ({signum})，正在关闭...")
+                print(f"收到关闭信号 ({signum})，正在关闭...", file=sys.stderr)
 
             sys.exit(0)
 
@@ -1465,32 +1496,40 @@ def main():
         signal.signal(signal.SIGTERM, shutdown_handler)
 
         # 6. 启动服务器
-        print("=" * 60)
-        print("[OK] Questions MCP Server 启动成功!")
-        print("=" * 60)
+        if not is_mcp_mode:
+            print("=" * 60)
+            print("[OK] Questions MCP Server 启动成功!")
+            print("=" * 60)
         logger.info("Questions MCP Server 启动成功")
         logger.info("服务器正在运行，等待客户端连接...")
-        print()
-        print("服务器正在运行...")
-        print("按 Ctrl+C 停止服务器")
-        print()
+        if not is_mcp_mode:
+            print()
+            print("服务器正在运行...")
+            print("按 Ctrl+C 停止服务器")
+            print()
 
         # 运行 MCP Server（这会阻塞直到服务器停止）
-        mcp_server.run()
+        # 在 MCP 模式下，隐藏 banner 避免干扰 STDIO 通信
+        mcp_server.run(show_banner=not is_mcp_mode)
 
     except KeyboardInterrupt:
-        print("\n\n收到中断信号，正在关闭...")
+        if not is_mcp_mode:
+            print("\n\n收到中断信号，正在关闭...")
         if logger:
             logger.info("收到中断信号，正在关闭服务器...")
     except Exception as e:
-        print(f"\n[ERROR] 启动失败: {e}")
+        if not is_mcp_mode:
+            print(f"\n[ERROR] 启动失败: {e}")
         if logger:
             logger.error(f"服务器启动失败: {e}")
+            import traceback
+            logger.error(traceback.format_exc())
         sys.exit(1)
     finally:
         if logger:
             logger.info("Questions MCP Server 已停止")
-        print("\n服务器已停止")
+        if not is_mcp_mode:
+            print("\n服务器已停止")
 
 
 if __name__ == "__main__":
